==> quarkus-resteasy-server-common-deployment-2.0.1.Final-sources.jar: io/quarkus/resteasy/server/common/deployment/ResteasyServerCommonProcessor$ResteasyConfig$$accessor.java <==
package io.quarkus.resteasy.server.common.deployment;
public final class ResteasyServerCommonProcessor$ResteasyConfig$$accessor {
    private ResteasyServerCommonProcessor$ResteasyConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_singletonResources(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).singletonResources;
    }
    @SuppressWarnings("unchecked")
    public static void set_singletonResources(Object __instance, boolean singletonResources) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).singletonResources = singletonResources;
    }
    @SuppressWarnings("unchecked")
    public static Object get_path(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).path;
    }
    @SuppressWarnings("unchecked")
    public static void set_path(Object __instance, Object path) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).path = (String)path;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_metricsEnabled(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).metricsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_metricsEnabled(Object __instance, boolean metricsEnabled) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).metricsEnabled = metricsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_ignoreApplicationClasses(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).ignoreApplicationClasses;
    }
    @SuppressWarnings("unchecked")
    public static void set_ignoreApplicationClasses(Object __instance, boolean ignoreApplicationClasses) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).ignoreApplicationClasses = ignoreApplicationClasses;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_buildTimeConditionAware(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).buildTimeConditionAware;
    }
    @SuppressWarnings("unchecked")
    public static void set_buildTimeConditionAware(Object __instance, boolean buildTimeConditionAware) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).buildTimeConditionAware = buildTimeConditionAware;
    }
    public static Object construct() {
        return new io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig();
    }
}

==> quarkus-resteasy-server-common-deployment-2.10.0.Final-sources.jar: io/quarkus/resteasy/server/common/deployment/ResteasyServerCommonProcessor$ResteasyConfig$$accessor.java <==
package io.quarkus.resteasy.server.common.deployment;
public final class ResteasyServerCommonProcessor$ResteasyConfig$$accessor {
    private ResteasyServerCommonProcessor$ResteasyConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_singletonResources(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).singletonResources;
    }
    @SuppressWarnings("unchecked")
    public static void set_singletonResources(Object __instance, boolean singletonResources) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).singletonResources = singletonResources;
    }
    @SuppressWarnings("unchecked")
    public static Object get_path(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).path;
    }
    @SuppressWarnings("unchecked")
    public static void set_path(Object __instance, Object path) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).path = (String)path;
    }
    @SuppressWarnings("unchecked")
    public static Object get_metricsEnabled(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).metricsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_metricsEnabled(Object __instance, Object metricsEnabled) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).metricsEnabled = (java.util.Optional<Boolean>)metricsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_ignoreApplicationClasses(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).ignoreApplicationClasses;
    }
    @SuppressWarnings("unchecked")
    public static void set_ignoreApplicationClasses(Object __instance, boolean ignoreApplicationClasses) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).ignoreApplicationClasses = ignoreApplicationClasses;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_buildTimeConditionAware(Object __instance) {
        return ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).buildTimeConditionAware;
    }
    @SuppressWarnings("unchecked")
    public static void set_buildTimeConditionAware(Object __instance, boolean buildTimeConditionAware) {
        ((io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig)__instance).buildTimeConditionAware = buildTimeConditionAware;
    }
    public static Object construct() {
        return new io.quarkus.resteasy.server.common.deployment.ResteasyServerCommonProcessor.ResteasyConfig();
    }
}
